/*
 * @Date: 2021-12-08 15:59:46
 * @LastEditors: JinxChen
 * @LastEditTime: 2022-08-06 10:24:13
 * @FilePath: \telpoAdminTemplate\src\utils\request.js
 * @description:
 */
import axios from 'axios'
import {
  Message
} from 'element-ui'
import store from '@/store'
/* import { getToken } from '@/utils/auth' */

// create an axios instance
const service = axios.create({
  baseURL: process.env.VUE_APP_BASE_API, // url = base url + request url
  // withCredentials: true, // send cookies when cross-domain requests
  /* timeout: 5000  */ // request timeout
})

// request interceptor
service.interceptors.request.use(
  config => {
    // do something before request is sent

    if (store.getters.token) {
      // let each request carry token
      // ['X-Token'] is a custom headers key
      // please modify it according to the actual situation
      config.headers['AuthToken'] = store.getters.token;
    }
    return config
  },
  error => {
    // do something with request error
    console.log(error) // for debug
    return Promise.reject(error)
  }
)

// response interceptor
service.interceptors.response.use(
  response => {
    const res = response.data
    if (res.code === 106) {
      // to re-login
      setTimeout(() => {
        store.dispatch('user/resetToken').then(() => {
          Message({
            message: '登录过期,请您重新登录!',
            type: 'error',
            duration: 1500
          })
          location.reload()
        })
      }, 1000)
    } else if (res.code === 0) {
      return res
    } else {
      Message({
        message: res.message || '出错了,请联系管理员！',
        type: 'error',
        duration: 3 * 1000
      })
      return Promise.reject(new Error(res.message))
    }
  },
  error => {
    console.log('err:', error) // for debug
    Message({
      message: error.message,
      type: 'error',
      duration: 3 * 1000
    })
    return Promise.reject(error)
  }
)

export default service
